@@ -5,7 +5,7 @@ import os
 import sys
 
 sys_lang_code = locale.getdefaultlocale()[0]
-locale_path = os.path.abspath(os.path.dirname(__file__))
+locale_path = locale_dir_path = os.path.abspath(os.path.dirname(__file__))
 locale_langcodes =  \
     [d for d in os.listdir(locale_path)
      if os.path.isdir(os.path.join(locale_path, d))]
