@@ -15,7 +15,8 @@ from xpinyin import Pinyin
 from primaryschool.dirs import *
 from primaryschool.locale import _
 from primaryschool.resource import (default_font, default_font_path,
-                                    get_default_font, get_font_path)
+                                    get_default_font, get_font_path,
+                                    get_resource_path)
 from primaryschool.subjects import *
 from primaryschool.subjects._templates_ import GameBase
 from primaryschool.subjects.yuwen.words import cn_ps_c
@@ -23,7 +24,7 @@ from primaryschool.subjects.yuwen.words import cn_ps_c
 # primaryschool.subjects.yuwen.g_pinyin_missile
 module_str = __name__
 
-name_t = _('pinyin missile')
+name_t = _('Pinyin Missile')
 
 difficulties = [
     _('Grade 1.1'),  # 0
@@ -66,11 +67,11 @@ class Word():
         if g < 12:
             words = cn_ps_c[g]
         elif g == 12:
-            words = cn_ps_c[0:6]
+            words = sum(cn_ps_c[0:6], [])
         elif g == 13:
-            words = cn_ps_c[6:16]
+            words = sum(cn_ps_c[6:16], [])
         elif g == 14:
-            words = cn_ps_c[0:16]
+            words = sum(cn_ps_c[0:16], [])
         return sum(words, [])
 
     def get_rand_words(self, n):
@@ -177,9 +178,9 @@ class WordSurfacesManager():
         self.win = self.pm.win
         self.moving_surfaces = []
         self.frame_counter = frame_counter
-        self.interval = 1.5 * self.pm.FPS
+        self.interval = 2.2 * self.pm.FPS
         self.intercept_interval = 0.3 * self.pm.FPS
-        self.moving_speed = 1
+        self.moving_speed = 0.8
         self.intercepted_color = (175, 10, 175, 100)
         self.laser_color = (0, 0, 255, 90)
         self.laser_width = 2
@@ -311,10 +312,10 @@ class InfoSurface():
         return (20, 255, 0) if self._pass else (255, 20, 0)
 
     def get_win_info(self):
-        return _('win: ') + str(self.pm.win_count) + '|' + _('lose: ') +\
-            str(self.pm.lose_count) + '|' + _('remain: ') +\
-            str(self.pm.wordsurfaces_manager.count()) + '|' +\
-            _('total: ') + str(self.pm.word_count)
+        return _('win: ') + str(self.pm.win_count) + '|' + _('lose: ') \
+            + str(self.pm.lose_count) + '|' + _('remain: ') \
+            + str(self.pm.wordsurfaces_manager.count()) + '|' \
+            + _('total: ') + str(self.pm.word_count)
 
     def get_win_info_dest(self):
         _w, _ = self.win_info_surface.get_size()
@@ -425,7 +426,7 @@ class WordSurface():
         self.size = self.get_size()
         self.dest = dest if dest else self.get_random_dest()
         self.center = self.get_center()
-        self.pinyin = self.get_pinyin()
+        self.pinyins = self.get_pinyins()
 
     def set_circle_color(self, color):
         self.circle_color = color
@@ -486,16 +487,20 @@ class WordSurface():
         return self.get_w() / 2
 
     def circle(self):
-        pygame.draw.circle(self.pm.surface, self.circle_color,
-                           self.center, self.get_circle_radius(),
-                           width=self.circle_width)
+        pygame.draw.circle(
+            self.pm.surface, self.circle_color,
+            self.center, self.get_circle_radius(),
+            width=self.circle_width)
 
     def intercept(self, _pinyin):
-        self.intercepted = self.pinyin in _pinyin
+        for p in self.pinyins:
+            self.intercepted = p in _pinyin
+            if self.intercepted:
+                break
         return self.intercepted
 
-    def get_pinyin(self):
-        return pinyin.get_pinyin(self.word, '')
+    def get_pinyins(self):
+        return pinyin.get_pinyins(self.word, tone_marks='numbers')
 
     def get_size(self):
         return self.surface.get_size()
@@ -564,6 +569,22 @@ class PinyinMissile(GameBase):
         self.start_time = datetime.now()
         self.end_time = None
 
+        self._bg_img = None
+
+    def set_bg_img(self, src_name=None):
+        self._bg_img = pygame.image.load(
+            get_resource_path(src_name if src_name else '0x4.png'))
+        self._bg_img = pygame.transform.scale(
+            self._bg_img, (self.w_width, self.w_height))
+
+    def get_bg_img(self):
+        if not self._bg_img:
+            self.set_bg_img()
+        return self._bg_img
+
+    def blit_bg_img(self):
+        self.surface.blit(self.get_bg_img(), (0, 0))
+
     def print_game_info(self):
         print(self.subject.name_t, name_t, difficulties[self.difficulty_index])
 
@@ -590,6 +611,12 @@ class PinyinMissile(GameBase):
                     self.input_surface._update()
                     return
 
+        if self.main_menu._menu.is_enabled():
+            self.main_menu._menu.update(events)
+
+        if self.play_menu._menu.is_enabled():
+            self.play_menu._menu.update(events)
+
     def load(self):
         try:
             self._load = True
@@ -615,7 +642,6 @@ class PinyinMissile(GameBase):
             pickle.dump(_copy, f)
 
     def _start(self):
-
         if not self._load:
             self.wordsurfaces_manager.set_surfaces()
 
@@ -625,31 +651,24 @@ class PinyinMissile(GameBase):
         self.wordsurfaces_manager.set_surfaces()
         self.start()
 
+    def blit_game_surface(self):
+        if self.win_count + self.lose_count < self.word_count:
+            self.info_surface.blit()
+            self.wall_surface.blit()
+            self.wordsurfaces_manager.blit()
+            self.input_surface.blit()
+        else:
+            self.info_surface.score_blit()
+
     def start(self):
 
         self._start()
 
         while self.running:
             self.clock.tick(self.FPS)
-
-            self.surface.fill((0, 0, 0))
-
-            events = pygame.event.get()
-            self.handle_events(events)
-            if self.main_menu._menu.is_enabled():
-                self.main_menu._menu.update(events)
-
-            if self.play_menu._menu.is_enabled():
-                self.play_menu._menu.update(events)
-
-            if self.win_count + self.lose_count < self.word_count:
-                self.info_surface.blit()
-                self.wall_surface.blit()
-                self.wordsurfaces_manager.blit()
-                self.input_surface.blit()
-            else:
-                self.info_surface.score_blit()
-
+            self.blit_bg_img()
+            self.handle_events(pygame.event.get())
+            self.blit_game_surface()
             pygame.display.update()
 
 
